@@ -26,30 +26,21 @@
 #include <gtk/gtk.h>
 #include <gdk/gdkx.h>
 
-#include <libmateui/libmateui.h>
 #include <unique/unique.h>
 
 #include "maximus-app.h"
 
-static gboolean on_sess_save (MateClient        *client,
-                              gint                arg1, 
-                              MateSaveStyle      arg2,
-                              gboolean            arg3,
-                              MateInteractStyle  arg4,
-                              gboolean            arg5);
+#ifdef __GNUC__
+#define UNUSED_VARIABLE __attribute__ ((unused))
+#else
+#define UNUSED_VARIABLE
+#endif
 
-static gboolean no_restart = FALSE;
 static gboolean version    = FALSE;
 gboolean no_maximize = FALSE;
 
 GOptionEntry entries[] = 
 {
- {
-   "no-restart", 's', 
-   0, G_OPTION_ARG_NONE, 
-   &no_restart, 
-   "Do not automatically restart (standalone)", NULL 
- },
  {
    "version", 'v', 
    0, G_OPTION_ARG_NONE, 
@@ -70,12 +61,15 @@ GOptionEntry entries[] =
 gint main (gint argc, gchar *argv[])
 {
   UniqueApp *unique;
-  MaximusApp *app;
-  MateClient *client;
+  MaximusApp UNUSED_VARIABLE *app;
   GOptionContext  *context;
-  gchar *exec[] = {"maximus"};
 
+#if GLIB_CHECK_VERSION (2, 32, 0)
+  /* g_thread_init (NULL); */
+#else
   g_thread_init (NULL);
+#endif
+
   g_set_application_name ("Maximus");
   
   gtk_init (&argc, &argv);
@@ -92,19 +86,6 @@ gint main (gint argc, gchar *argv[])
   g_option_context_add_group (context, gtk_get_option_group (TRUE));
   g_option_context_parse (context, &argc, &argv, NULL);
   g_option_context_free(context);  
-  
-  if (!no_restart)
-  {
-    mate_program_init ("mate-maximus", "1.3.0", LIBMATEUI_MODULE, argc, argv,
-                        MATE_PARAM_NONE, NULL);
-
-    client = mate_master_client ();
-    mate_client_set_restart_command (client, 1, exec);
-    mate_client_set_restart_style (client, MATE_RESTART_IMMEDIATELY);
-
-    g_signal_connect (client, "save-yourself", 
-                      G_CALLBACK (on_sess_save), NULL);
-  }
 
   gdk_error_trap_push ();
   app = maximus_app_get_default ();
@@ -114,13 +95,3 @@ gint main (gint argc, gchar *argv[])
 
   return EXIT_SUCCESS;
 }
-
-static gboolean on_sess_save (MateClient        *client,
-                              gint                arg1, 
-                              MateSaveStyle      arg2,
-                              gboolean            arg3,
-                              MateInteractStyle  arg4,
-                              gboolean            arg5)
-{
-  return TRUE;
-}
